<?php
/**
 * Plugin Name: Role Based Hide Adminbar
 * Description: Hide Adminbar based on User Role.
 * Author: Yasir Khalifa
 * Author URI: https://myasark.wordpress.com/
 * Version: 1.0.3
 * License: GPLv2
 */
// Exit if accessed directly.
if (!defined('ABSPATH')) exit;
class RBHAbar {
    function __construct() {
        add_action('admin_init', array($this, 'rbhabar_register_settings'));
        add_action('admin_enqueue_scripts', array($this, 'load_admin_style'));
        add_action('admin_menu', array($this, 'rbhabar_register_options_page'));
        add_action('after_setup_theme', array($this, 'rbhabar_remove_admin_bar'));
    }
    function rbhabar_register_settings() {
        add_option('rbhabar_options_name');
        register_setting('rbhabar_options_group', 'rbhabar_options_name');
    }
   function load_admin_style($hook) { 
        if( $hook == 'settings_page_rbhabar-setting' ) {
        wp_register_style('rbhabar_css', plugins_url('/assets/css/custom.css', __FILE__));
        wp_enqueue_style('rbhabar_css');
     }
    }
    function rbhabar_register_options_page() {
        add_options_page('Hide Adminbar', 'Hide Adminbar', 'manage_options', 'rbhabar-setting', array($this, 'rbhabar_options_page'));
    }
    function rbhabar_options_page() {
    ?>
	  <div class="container"> 
	   <h2>Hide Adminbar</h2>
		  <form method="post" action="options.php">
		  <?php settings_fields('rbhabar_options_group'); ?>
		  <p>Select Role for hide admin bar</p>  
		  <?php global $wp_roles;
				$role_exists = get_option('rbhabar_options_name');
				foreach ($wp_roles->roles as $key => $value): ?>
			   <div><input type="checkbox" name="rbhabar_options_name[]" id="<?php echo $value['name']; ?>" value="<?php echo $key; ?>"<?php if ($role_exists) { if (in_array($key, $role_exists)) { echo "checked='checked'";}	} ?>>
				   <label for="<?php echo $value['name']; ?>"><?php echo $value['name']; ?></label></div>
					<br/>
			<?php endforeach; ?>
		  <?php submit_button(); ?>
		  </form>
	  </div>
    <?php
    }
    function rbhabar_remove_admin_bar() {
        $role_exists = get_option('rbhabar_options_name');
        if (is_array($role_exists) || is_object($role_exists)) {
            foreach ($role_exists as $role_exist) {
                if (current_user_can($role_exist)) {
                    show_admin_bar(false);
                }
            }
        }
    }
}
$RBHAbar = new RBHAbar();
function rbhabar_remove() {
    delete_option('rbhabar_options_name');
    unregister_setting('rbhabar_options_group', 'rbhabar_options_name');
}
register_deactivation_hook(__FILE__, 'rbhabar_remove');